# -*- coding: utf-8 -*-

from distutils.core import setup
setup(
  name = 'balu',
  packages = ['balu'],
  version = '0.1',
  description = 'Python implementation of Balu Toolbox by Domingo Mery (http://dmery.ing.puc.cl/index.php/balu/)',
  author = 'Diego Patiño',
  author_email = 'dapatinoco@unal.edu.com',
  url = 'https://github.com/dipaco/balu-python',
  download_url = 'https://github.com/dipaco/balu-python/releases/tag/v0.1.0',
  keywords = ['Computer Vision', 'Machine Learning', 'Image Processing'],
  classifiers = [],
)
